@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2015 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #define SOLARUS_FIRE_H
 
 #include "solarus/Common.h"
-#include "solarus/entities/Detector.h"
+#include "solarus/entities/Entity.h"
 #include <string>
 
 namespace Solarus {
@@ -28,21 +28,22 @@ namespace Solarus {
  *
  * Fire can interact with entities.
  */
-class Fire: public Detector {
+class Fire: public Entity {
 
   public:
 
-    Fire(const std::string& name, Layer layer, const Point& xy);
+    static constexpr EntityType ThisType = EntityType::FIRE;
+
+    Fire(const std::string& name, int layer, const Point& xy);
 
     virtual EntityType get_type() const override;
-    virtual bool can_be_obstacle() const override;
 
     // state
     virtual void update() override;
 
     // collisions
     virtual void notify_collision(
-        MapEntity& other_entity,
+        Entity& other_entity,
         Sprite& this_sprite,
         Sprite& other_sprite
     ) override;
