@@ -45,9 +45,9 @@ class ParallaxScrollingTilePattern: public SimpleTilePattern {
     virtual void draw(
         const SurfacePtr& dst_surface,
         const Point& dst_position,
-        Tileset& tileset,
+        const Tileset& tileset,
         const Point& viewport
-    ) override;
+    ) const override;
 
     virtual bool is_animated() const override;
     virtual bool is_drawn_at_its_position() const override;
