@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2015 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,18 +17,18 @@
 #ifndef SOLARUS_HERO_BOW_STATE_H
 #define SOLARUS_HERO_BOW_STATE_H
 
-#include "solarus/hero/State.h"
+#include "solarus/hero/HeroState.h"
 
 namespace Solarus {
 
 /**
  * \brief The state "bow" of the hero.
  */
-class Hero::BowState: public Hero::State {
+class Hero::BowState: public HeroState {
 
   public:
 
-    BowState(Hero& hero);
+    explicit BowState(Hero& hero);
 
     virtual void start(const State* previous_state) override;
     virtual void update() override;
@@ -40,4 +40,3 @@ class Hero::BowState: public Hero::State {
 }
 
 #endif
-
