@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2015 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #ifndef SOLARUS_HERO_LIFTING_STATE_H
 #define SOLARUS_HERO_LIFTING_STATE_H
 
-#include "solarus/hero/State.h"
+#include "solarus/entities/EntityState.h"
 #include <memory>
 
 namespace Solarus {
@@ -25,23 +25,23 @@ namespace Solarus {
 /**
  * \brief The state "Lifting" of the hero.
  */
-class Hero::LiftingState: public Hero::State {
+class Hero::LiftingState: public HeroState {
 
   public:
 
-    LiftingState(Hero& hero, const std::shared_ptr<CarriedItem>& lifted_item);
+    LiftingState(Hero& hero, const std::shared_ptr<CarriedObject>& lifted_item);
 
     virtual void start(const State* previous_state) override;
     virtual void stop(const State* next_state) override;
     virtual void update() override;
     virtual void set_suspended(bool suspended) override;
-    virtual bool can_be_hurt(MapEntity* attacker) const override;
+    virtual bool can_be_hurt(Entity* attacker) const override;
 
   private:
 
     void throw_item();
 
-    std::shared_ptr<CarriedItem> lifted_item;    /**< the item currently being lifted */
+    std::shared_ptr<CarriedObject> lifted_item;    /**< the item currently being lifted */
 };
 
 }
