@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2015 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
  * 
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #ifndef SOLARUS_HERO_INVENTORY_ITEM_STATE_H
 #define SOLARUS_HERO_INVENTORY_ITEM_STATE_H
 
-#include "solarus/hero/State.h"
+#include "solarus/hero/HeroState.h"
 #include "solarus/EquipmentItemUsage.h"
 
 namespace Solarus {
@@ -25,7 +25,7 @@ namespace Solarus {
 /**
  * \brief The state "using equipment item" of the hero.
  */
-class Hero::UsingItemState: public Hero::State {
+class Hero::UsingItemState: public HeroState {
 
   public:
 
