@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2015 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ class SOLARUS_API RandomPathMovement: public PathMovement {
 
   public:
 
-    RandomPathMovement(int speed);
+    explicit RandomPathMovement(int speed);
 
     virtual void update() override;
     virtual bool is_finished() const override;
